######################################################easymod########################################################
## MOD Title: SmartFeed
## MOD Author: MarkDHamill < mhamill@computer.org > (Mark D. Hamill) http://pbpbb.potomactavern.org
## MOD Description: Provides RSS 0.91, RSS 1.0, RSS 2.0, Atom 1.0 customized newsfeeds. Users select forums
##           they want, including protected forums if they can access them. Private messages and ads in 
##			 newsfeed are supported.
## MOD Version: 1.1
##
## Installation Level: Easy
## Installation Time: 5 Minutes or less
##
## Files To Edit:	lang_faq.php,
##					page_header.php,
##					overall_header.tpl
## Included Files:	feedcreator.class.php,
##			smartfeed.php,
##			smartfeed_url.php,
##			smartfeed_url_body.tpl
##			lang_smartfeed.php (for /language/lang_english, /language/lang_german, /language/lang_french and /language/lang_dutch)
##          smartfeed_constants.php
##          icon_mini_feed.gif
##			smartfeed_ads.class.php
##			smartfeed_advertising.txt
## License: http://opensource.org/licenses/gpl-license.php GNU General Public License v2 
##############################################################
## For security purposes, please check: http://www.phpbb.com/mods/
## for the latest version of this MOD. Although MODs are checked
## before being allowed in the MODs Database there is no guarantee
## that there are no security problems within the MOD. No support
## will be given for MODs not found within the MODs Database which
## can be found at http://www.phpbb.com/mods/
##############################################################
## Author Notes:
##
## phpBB forums may contain restricted forums that should not normally be exposed as a newsfeed. Smartfeed
## is a phpBB modification, derived from my phpBB Email Digests modification, that allows users to get a newsfeed
## for selected forums, including restricted forums if they have the privilege. This is done by using an 
## interface program called smartfeed_url.php which creates a URL that authenticates the user with phpBB.
## Smartfeed is smart enough to keep users out of forums for which they do not have access, even if they hack
## parameters on the URL field. Authentication is reasonably sophisticated. Those who are not registered can 
## access in the newsfeed only those forums that can be read by the public.
##
## The URL generated by smartfeed_url.php is then copied and pasted by the user into their newsreader. The user
## needs to be smart enough to specify a newsfeed that their newsreader can interpret. RSS 0.91, RSS 1.0, RSS 2.0
## and ATOM 1.0 newsfeeds are supported. RSS 2.0 is the default.
##
## Rather than reinvent the wheel, this mod uses the FeedCreator PHP class originally written by Kai Blankenhorn,
## but extended by Scott Reynen and Dirk Clemen, with on the fly feed code added by Fabian Wolf and ATOM 1.0 support 
## added by Mohammad Hafiz bin Ismail. I modified a few lines of the class (see comments in the class with MDH in them).
##
## This has been tested, but not extensively, by validating reasonably complex feeds for RSS 0.91, RSS 1.0, RSS 2.0 and 
## ATOM 1.0 at http://feedvalidator.org.
##
## It has been tested on a MySQL 4.1 environment only but should be DBAL compliant.
##
## *** YOU MUST DO THIS IN ADDITION TO USING EASYMOD TO INSTALL THIS MOD ***
##
## Please edit the $siteURL variable in /includes/smartfeed_constants.php with a text editor like Notepad. Simply 
## give it the full URL to your phpBB forums, leaving ON the / at the end. By default the script will try to create the URL,
## but for most people it will not work. Example:
##
##   define('SMARTFEED_SITE_URL', 'http://www.mysite.com/phpBB2/');
##
## After installation:
##
##	 - You may not like some of the default behavior in Smartfeed. Behavior is controlled in the file /includes/smartfeed_constants.php.
##	   Here are some constants you may wish to consider changing:
##			SMARTFEED_RFC1766_LANG - if you are using a language other than English.
##			SMARTFEED_FEED_IMAGE_PATH - you may wish to have your newsfeed show an image other than the phpBB logo
##			SMARTFEED_HIDE_ADVERTISING_INTERFACE - if you never plan to show ads, set this value to true and you will not be
##				bothered by the interface that shows for administrators when smartfeed_url.php is run.
##   - To try it out, click on the Smartfeed icon that should now appear on the header of each page of your board. After pressing Generate, 
##	   copy and paste the resulting complex URL into your newsreader. The whole URL may not show in the field, so make sure you have
##	   copied the whole field. An easy way to do this with Windows is to selecting or click on the field, press CTRL-A then CTRL-C.
##   - Run your newsreader using the copied URL and enjoy the results. If you are looking for a newsreader, an easy (and free) one to get
##	   going is Sage for Firefox. First install the latest version of Firefox, then install the Sage newsreader extension. Details are at:
##			http://sage.mozdev.org/
##	 - If you want your forums to automatically advertise your feed so your board is seen as feed accessible by browsers, do this:
##		1. VERY IMPORTANT: Log out of your forum. You don't want to pass out an encryption key to the public that will show all your forums!
##		2. Click on "Smartfeed" on your board as a public user. Create a URL. The following conditions are recommended:
##			a. Select RSS 2.0
##			b. Show posts for last 24 hours. (Set this lower if your board is highly trafficked)
##			c. It is suggested that you keep other items the default, although you can change then as you feel wise for your board.
##			d. Copy and paste the URL to the clipboard temporarily.
##		3. Modify overall_header.tpl in /templates/subSilver/. On the line immediately after the <title> tag enter the following. Change
##			xxx to the value provided by smartfeed_url.php. Of course remove the ## comments characters! 
##			<link rel="alternate" type="application/rss+xml" title="RSS" href="xxx" />
##		   An example:
##			<link rel="alternate" type="application/rss+xml" title="RSS" href="http://www.potomactavern.org/smartfeed.php?feed_type=RSS2.0&limit=1%20DAY&sort_by=standard&max_word_size=All" />
##		4. Save overall_header.tpl.
##		5. Try it out. For example in Firefox you should see the RSS Icon near the URL field. Clicking on this icon in Firefox 2.0 or greater should 
##		   provide an easy way to include the feed in your newsreader.
##
## While this mod is free, if you want to encourage me to keep it up to date or write other similar mods, feel free to send me 
## a donation of $10 or more. My PayPal account is mhamill@computer.org.
##
## This MOD is EasyMOD Friendly! However there is more to do to install Smartfeed than using EasyMod. Read this file!
##
##############################################################
## MOD History:
##
##   2005-12-29 - Version 0.0.0
##      - First Alpha version for comments
##   2006-01-01 - Version 0.0.1
##      - Password is now encrypted using $dbpasswd, drastically reducing the likelihood the phpBB password can be hacked
##		- Incorporated Conditional Get logic found at http://simon.incutio.com/archive/2003/04/23/conditionalGet. Returns HTTP 304
##        if there are no new posts, saving a lot of bandwidth!
##   2006-01-02 - Version 0.0.2
##      - Added optional IP Authentication. If selected the URL cannot be "hijacked". For example, someone cannot use the URL at
##		  work if it was created at home. For sites with sensitive information this may be an issue.
##      - $siteURL adds a "/" to the end if needed 
##   2006-01-06 - Version 0.1 (First Beta)
##      - Works with EasyMod
##      - If there is an error the error message appears in the newsfeed itself, instead of returning a HTML page
##      - Now allows access by non registered people to public forums only
##		- Administrator can set a maximum number of items to be returned in a newsfeed
##		- Sets and uses a cookie to determine when newsfeed was last requested
##   2006-01-21 - Version 0.2 
##      - Fixed bug in smartfeed_url.php. Creates $siteURL value similar to smartfeed.php
##		- User can elect to filter out their own posts, similar to Digest mod
##		- Changed feedcreator.class.php to return RSS 1.0 and RSS 2.0 to have a MIME type of text/xml. While
##		  the validator at feedcreator.org complains it has to be type application/xml if selected from browsers like
##		  Firefox it wants to download it as a file. I think this is too confusing at the moment. ATOM 1.0 MIME type also
##		  returned to type application/xml.
##		- Note: the store cookie feature that stores the last access time still needs some thought. It works fine for browser plug ins
##        like Sage, but otherwise probably won't work. Stand alone feed readers will likely ignore cookies, as will web aggregator sites
##		  like bloglines.com.
##		- If you installed version 0.1 make sure to reinstall all files!
##   2006-01-28 - Version 0.3
##		- Pretty important bug found: password was not encrypting correctly. Reinstall all files and use smartfeed_url.php to regenerate
##		  the URL to use. Make sure anyone using the Beta version to date updates the URLs. Otherwise they will get smartfeed errors.
##		- Smilies path now corrected. Most newsreaders will show smily images.
##		- smartfeed_url_body.tpl Javascript corrected so that when All Forums is unchecked the forums underneath are also unchecked. This
##		  used to work but got corrupted when I added <span> tags.
##		- smartfeed_url_body.tpl also is now WAI and Section 508 compliant, which mostly involved adding a lot of <label> tags.
##   2006-02-20 - Version 0.4 (Hopefully final Beta version!)
##      - Fixed Smilies URL problem
##      - An appropriate error message is generated if no arguments are used calling smartfeed.php
##      - Included xml.gif image. Does not need to be used but can be used to link to smartfeed_url.php.
##      - Included change to lang_faq.php to add a FAQ question about newsfeeds
##		- Added a smartfeeds_constant.php include file, to fully separate out the non-language components of lang_constants.php
##		- Tweaked feedcreator.class.php a bit in order to remove some feed validator warnings
##   2006-02-25 - Version 1.0 (Production Release, if the phpBB gods approve)
##		- Took out all MySQL specific functions and created equivalent functionality in PHP. Hopefully software is now DBAL compliant.
##		- Renamed some variables to more accurately describe their functions
##		- Moved fake email address to smartfeed_constants.php where it belongs
##   2006-02-26 - Version 1.0.1
##      - Fixed minor bug that wasn't showing the post time in the message text in smartfeed.php
##	 2006-03-01 - Version 1.0.2
##		- Changed one line of SQL in smartfeed.php which might cause a problem for those not using MySQL.
##   2006-03-05 - Version 1.0.3
##		- Fixed Line 325 in smartfeed.php that did not limit number of messages for public users.
##		- Fixed Line 42 in lang_smartfeed.php to use SITE_URL constant vs. old $siteURL variable in message.
##	 2006-03-12 - Version 1.0.4
##		- Made changes to smartfeed.php requested by phpBB Mod Team including:
##			-- Replaced $_GET and $_SERVER with older but more portable $HTTP_GET_VARS and $HTTP_SERVER_VARS
##			-- Replaced html_entity_decode function which requires PHP 4.3.0 with a entity_decode funtion that calls html_entity_decode if
##			   it exists, otherwise it emulates it with a function found on php.net
##			-- Replace a few harcode .php text strings in lang_smartfeed.php with $phpEx
##	 2006-05-13 - Version 1.0.5
##		- "Category Order, Forum Order, Forum Topic Last Post Time (Desc) Topic Post Date/Time" is now called Standard Order
##		- Added two new sort types, "Standard Order, Last Posts First" and "Post Date/Time, Last Post First". In "Post Date/Time, Last Post First"
##		  you can also select the maximum number of posts to return. (It is difficult to make this logic work for the other sort types, given the
##		  limitations of SQL, so the field is hidden for other sort types.)
##		- Item title now includes author name when the post subject is left blank. This helps distinguish posts in the newsreader since most will
##		  have the same post subject.
##		- You can specify the maximum number of words per post to appear in the newsfeed. This is not recommended, however, as it may lead to
##		  validation warnings or even errors, due to poorly formatted and embedded HTML in the feed.
##		- The board administrator can require IP authentication for all users. This is done by changing this line in /includes/smartfeed_constants.php to true:
##			define('SMARTFEED_REQUIRE_IP_AUTHENTICATION', false); 
##		- Warning: if IP authentication is turned on, it is possible that a feed error will occur if the reader previously had turned that off. This can be fixed
##			by each reader rerunning smartfeed_url.php and copying the new URL into their newsreader.
##		- You can change how how the time of the post appears in the feed item by changing this line in /includes/smartfeed_constants.php:
##			define('SMARTFEED_DATE_FORMAT', 'd M Y h:i A '); 
##		- A Dutch translation is now available, thanks to Nic Mertens <nicmertens@telenet.be>, and is included.
##		- Version of Smartfeed now displays in feed and in smartfeed_url.php. This might help in the future solving problems. 
##	 2007-01-15 - Version 1.1
##		- Thanks yous
##			- My sincere thanks and appreciation to Sylvain Bourdon for his extensive testing, practical suggestions as well as his help in providing a 
##			  French translation.
##			- My sincere thanks also to Ewald Bayer for a German translation.
##			- My thanks to phpBB user LimitForums, who created the cool Smartfeed icon
##		- New features
##			- French language support provided by Sylvain Bourdon
##			- German language support provided by Ewald Bayer
##			- A reader's unread private messages since their last visit will appear in the newsfeed if they select the option in smartfeed_url.php. These 
##		  	  private messages appear first in the feed. The item link provides a URL to respond to the private message. Unread private messages remain in 
##		  	  the feed until they visit the board. 
##			- Smartfeed now displays optional advertising. The Administrators will see an extra screen when they invoke smartfeed_url.php where they can set 
##		  	  and enable/disable advertising information. Ads can be at the top and bottom of the feed, and after every X items in the feed. Sections can be turned on 
##		  	  or off, or a master switch can turn all advertising on or off. In addition, ads can be served only to public users, in case you don't want to annoy your 
##		  	  users with advertising. The whole advertising interface can be hidden by setting SMARTFEED_HIDE_ADVERTISING_INTERFACE to false. Known issue: IE 7 (and 
##		  	  possibly other newsreaders) can sort newsfeeds items by Date, Title or Author on the fly. This unfortunately might place the location of ads in the 
##		  	  feed at locations other than where they were anticipated.
##			- phpBB look and feel to posts in the feed. You should now usually see embedded URLs, images, and generally anything in BBcode. Some newsreaders
##		  	  do a better job than others of this. For example IE 7.0 will show bold, italicized and underlined while Sage for Firefox will not.
##			- New constant SMARTFEED_PRIVACY_MODE. If true (default), real user email addresses are not shown in the feed for public users and a fake email address is 
##		  	  substituted if necessary to validate the feed. Signature blocks are not shown to public users either. This is set to true by default. The idea 
##		  	  is to keep spammers from having yet another way to harvest email addresses.
##			- When selecting new topics only, a user is presented with a checkbox for first post only. If they select it the feed will contain only the first 
##		  	  post for new topics within the time period they specified.
##			- Post times shows the time in the user's local time based on the timezone in their phpBB profile.
##			- User name and posting time are no longer in the item description. This was redundant because other information in the item provides the same 
##			  information (although your newsreader may not show it).
##			- Topic replies can show or not show the phpBB Username in the item title. Use the constant SMARTFEED_SHOW_USERNAME_IN_REPLIES to toggle this switch. 
##		  	  It is set to true by default. Caution: some newsreaders will not display the item author, so setting this to false may confuse all readers as to who 
##		  	  is replying.
##			- New constant SMARTFEED_SUPPRESS_FORUM_NAMES. If set to true, the forum name will not appear in the item's title.
##			- If a user's account is deleted and the feed URL is used after deletion, the feed returns an error message suggesting that their account may 
##		  	  have been deleted. Previously the message was ambiguous as to what might have been the cause.
##			- User entered post text pulled from the database are filtered to remove characters likely to cause parser errors. This is typically a result of placing
##		  	  Windows-1252 characters in the post text. Since the feed is supposed to be ISO-8859-1, these deviant characters like curly quotes must be removed
##		  	  or the feed may not validate. That in turn will cause some parsers to raise an error, which will mean no feed is rendered. There was no eloquent way to  
##		  	  do this, so ISO-8859-1 is used as a filter. The result may be some strange looking characters from time to time in the feed, but at least the feed 
##			  will validate.
##		- Bugs fixed
##			- Fixed serious bug that allowed hackers to get access to a forum with a bad encrypted password. 
##			- Fixed bug that might have shown duplicate forum names in smartfeed_url.php for some boards
##			- If an Administrator is receiving digests, all forums are shown by digests.php. There is no need to have appropriate usergroup permissions.
##			- If a Moderator is receiving digests, all forums with moderator read permissions are shown by digests.php. There is no need to have appropriate 
##		  	  usergroup permissions for moderator only forums.
##		- Miscellaneous
##			- Removed IE specific Javascript from smartfeed_url_body.tpl. We can assume a HTML 4.0 browser now, so it is not needed. 
##			- Improved logic in unCheckAllForums so that if all individual forums are subscribed the All Subscribed Forums checkbox is checked.
##			- Smartfeed session is removed when smartfeed.php ends, thus reducing the number of sessions in the session table so it reflects users accessing board,
##		  	  not the feed.
##			- RSS 2.0 is now the default newsfeed type vs. Atom. RSS 2.0 seems to have the most traction.
##			- Installation instructions are included on this page so Smartfeed can automatically advertise that your phpBB board is accessible as a newsfeed.
##			- $lang['smartfeed_user_table_count_error'] has better description to indicate if this error occurs the user_id was probably deleted.
##	 2007-xx-xx - Version 1.x (In Development)
##		- Log access in table and provide related access reports.
##		- Rotate banner ads in middle section
##		- Keep ad statistics?
##		- If you have feature requests, send them to mhamill@computer.org. Put phpBB in the subject line to get past my spam filter.
##		- Give more thought on how to effectively present ads when browsers like IE allows them to be sorted after loading in a different order than anticipated.
##
##############################################################
## Before Adding This MOD To Your Forum, You Should Back Up All Files Related To This MOD
##############################################################
# 
#-----[ COPY ]------------------------------------------
#
copy smartfeed.php to smartfeed.php
copy smartfeed_url.php to smartfeed_url.php
copy cache/smartfeed_advertising.txt to cache/smartfeed_advertising.txt
copy includes/feedcreator.class.php to includes/feedcreator.class.php
copy includes/smartfeed_ads.class.php to includes/smartfeed_ads.class.php
copy includes/smartfeed_constants.php to includes/smartfeed_constants.php
copy language/lang_dutch/lang_smartfeed.php to language/lang_dutch/lang_smartfeed.php
copy language/lang_english/lang_smartfeed.php to language/lang_english/lang_smartfeed.php
copy language/lang_french/lang_smartfeed.php to language/lang_french/lang_smartfeed.php
copy language/lang_german/lang_smartfeed.php to language/lang_german/lang_smartfeed.php
copy templates/subSilver/smartfeed_url_body.tpl to templates/subSilver/smartfeed_url_body.tpl
copy templates/subSilver/images/icon_mini_feed.gif to templates/subSilver/images/icon_mini_feed.gif
#
#-----[ OPEN ]------------------------------------------
#
language/lang_english/lang_faq.php

#
#-----[ FIND ]------------------------------------------
#
//
// This ends the FAQ entries
//

#
#-----[ BEFORE, ADD ]------------------------------------------
#
// Begin Smartfeed 1.1 Modification
$faq[] = array("--","Newsfeeds");
$faq[] = array("Are your forums accessible as a newsfeed using RSS and Atom protocols?","Yes. This site has installed the Smartfeed phpBB modification, which allows access to both our public and private forums. Accessing private forums requires appropriate authorizations. <a href=\"./smartfeed_url.php\">Learn more.</a>"); 
// End Smartfeed 1.1 Modification

#
#-----[ OPEN ]------------------------------------------
#
language/lang_dutch/lang_faq.php

#
#-----[ FIND ]------------------------------------------
#
?>

#
#-----[ BEFORE, ADD ]------------------------------------------
#
// Begin Smartfeed 1.1 Modification
$faq[] = array("--","Newsfeeds");
$faq[] = array("Is dit forum bereikbaar als een newsfeed, gebruikmakend van RSS en Atom protocols?","Ja. Dit forum is uitgerust met de Smartfeed phpBB modificatiz, waarmee je toegang krijgt tot zowel publieke en private forums. Om private forums te bereiken dien je wel over de juiste autorisatie te beschikken. <a href=\"./smartfeed_url.php\">Hier vind je meer.</a>"); 
// End Smartfeed 1.1 Modification

#
#-----[ OPEN ]------------------------------------------
#
language/lang_german/lang_faq.php
#
#-----[ FIND ]------------------------------------------
#
//
// This ends the FAQ entries
//

#
#-----[ BEFORE, ADD ]------------------------------------------
#
// Begin Smartfeed 1.1 Modification
$faq[] = array("--","Newsfeeds");
$faq[] = array("Knnen die Foren als Newsfeeds, das RSS- und Atom-Protokoll nutzend abonniert werden?","Ja. Fr diese Seite ist die phpBB-Erweiterung Smartfeed installiert. Smartfeed ermglicht den Zugang zu ffentlichen und nicht ffentlichen Foren. Nichtffentliche Foren knnen nur abonniert werden, wenn ihr eingelgt seid. <a href=\"./smartfeed_url.php\">Weitere Infos zu Smartfeed findest Du hier.</a>"); 
// End Smartfeed 1.1 Modification

#
#-----[ OPEN ]------------------------------------------
#
language/lang_french/lang_faq.php
#
#-----[ FIND ]------------------------------------------
#
//
// This ends the FAQ entries
//

#
#-----[ BEFORE, ADD ]------------------------------------------
#
// Begin Smartfeed 1.1 Modification
$faq[] = array("--","Flux de nouvelles");
$faq[] = array("Est-ce que vos forums sont accessibles via un flux de nouvelles utilisant les protocoles RSS et Atom?","Oui. Ce site utilise le module phpBB SmartFeed, lequel permet l'accs  nos forums publics et privs. L'accs aux forums privs requiert les autorisations appropries. <a href=\"./smartfeed_url.php\">Plus d'info.</a>"); 
// End Smartfeed 1.1 Modification

#
#-----[ OPEN ]------------------------------------------
#
includes/page_header.php

#
#-----[ FIND ]------------------------------------------
#
define('HEADER_INC', TRUE);
#
#-----[ AFTER, ADD ]------------------------------------------
#
// Begin Smartfeed 1.1 Modification
include($phpbb_root_path . 'language/lang_' . $board_config['default_lang'] . '/lang_smartfeed.' . $phpEx);
// End Smartfeed 1.1 Modification
#
#-----[ FIND ]------------------------------------------
#
	'L_MEMBERLIST' => $lang['Memberlist'], 
#
#-----[ AFTER, ADD ]------------------------------------------
#
	// Begin Smartfeed 1.1 Modification
	'L_FEED' => $lang['smartfeed_page_title'], 
	// End Smartfeed 1.1 Modification
#
#-----[ FIND ]------------------------------------------
#
	'U_MEMBERLIST' => append_sid('memberlist.'.$phpEx), 
#
#-----[ AFTER, ADD ]------------------------------------------
#
	// Begin Smartfeed 1.1 Modification
	'U_FEED' => append_sid('smartfeed_url.'.$phpEx), 
	// End Smartfeed 1.1 Modification
#
#-----[ OPEN ]------------------------------------------
#
templates/subSilver/overall_header.tpl

#
#-----[ FIND ]------------------------------------------
#
						<td align="center" valign="top" nowrap="nowrap"><span class="mainmenu">&nbsp;<a href="{U_FAQ}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_faq.gif" width="12" height="13" border="0" alt="{L_FAQ}" hspace="3" />{L_FAQ}</a>&nbsp; &nbsp;<a href="{U_SEARCH}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_search.gif" width="12" height="13" border="0" alt="{L_SEARCH}" hspace="3" />{L_SEARCH}</a>&nbsp; &nbsp;<a href="{U_MEMBERLIST}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_members.gif" width="12" height="13" border="0" alt="{L_MEMBERLIST}" hspace="3" />{L_MEMBERLIST}</a>&nbsp; &nbsp;<a href="{U_GROUP_CP}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_groups.gif" width="12" height="13" border="0" alt="{L_USERGROUPS}" hspace="3" />{L_USERGROUPS}</a>&nbsp; 
#
#-----[ IN-LINE FIND ]------------------------------------------
#
&nbsp;<a href="{U_GROUP_CP}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_groups.gif" width="12" height="13" border="0" alt="{L_USERGROUPS}" hspace="3" />{L_USERGROUPS}</a>&nbsp;
#
#-----[ IN-LINE AFTER, ADD ]------------------------------------------
#
 &nbsp;<a href="{U_FEED}" class="mainmenu"><img src="templates/subSilver/images/icon_mini_feed.gif" width="12" height="13" border="0" alt="{L_FEED}" hspace="3" />{L_FEED}</a>&nbsp;

#
#-----[ SAVE/CLOSE ALL FILES ]------------------------------------------
#
#
# EoM  